====================================
Reusable Django apps with setuptools
====================================

This is a python module to enable Django to load reusable, pluggable and
egg-based applications -- think of ``plugins`` or ``components``.
It requires a recent Django SVN checkout and current setuptools.

For detailed installation instructions please have a look at INSTALL.txt.
